==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/outputs/IntegrationRuntimeSsisPropertiesResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.outputs

import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 * SSIS properties for managed integration runtime.
 * @property catalogInfo Catalog information for managed dedicated integration runtime.
 * @property credential The credential reference containing authentication information.
 * @property customSetupScriptProperties Custom setup script properties for a managed dedicated integration runtime.
 * @property dataProxyProperties Data proxy properties for a managed dedicated integration runtime.
 * @property edition The edition for the SSIS Integration Runtime
 * @property expressCustomSetupProperties Custom setup without script properties for a SSIS integration runtime.
 * @property licenseType License type for bringing your own license scenario.
 * @property packageStores Package stores for the SSIS Integration Runtime.
 */
public data class IntegrationRuntimeSsisPropertiesResponse(
    public val catalogInfo: IntegrationRuntimeSsisCatalogInfoResponse? = null,
    public val credential: CredentialReferenceResponse? = null,
    public val customSetupScriptProperties: IntegrationRuntimeCustomSetupScriptPropertiesResponse? =
        null,
    public val dataProxyProperties: IntegrationRuntimeDataProxyPropertiesResponse? = null,
    public val edition: String? = null,
    public val expressCustomSetupProperties: List<Any>? = null,
    public val licenseType: String? = null,
    public val packageStores: List<PackageStoreResponse>? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.datafactory.outputs.IntegrationRuntimeSsisPropertiesResponse):
            IntegrationRuntimeSsisPropertiesResponse = IntegrationRuntimeSsisPropertiesResponse(
            catalogInfo = javaType.catalogInfo().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.datafactory.kotlin.outputs.IntegrationRuntimeSsisCatalogInfoResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            credential = javaType.credential().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.datafactory.kotlin.outputs.CredentialReferenceResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            customSetupScriptProperties = javaType.customSetupScriptProperties().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.datafactory.kotlin.outputs.IntegrationRuntimeCustomSetupScriptPropertiesResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            dataProxyProperties = javaType.dataProxyProperties().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.datafactory.kotlin.outputs.IntegrationRuntimeDataProxyPropertiesResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            edition = javaType.edition().map({ args0 -> args0 }).orElse(null),
            expressCustomSetupProperties = javaType.expressCustomSetupProperties().map({ args0 -> args0 }),
            licenseType = javaType.licenseType().map({ args0 -> args0 }).orElse(null),
            packageStores = javaType.packageStores().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.datafactory.kotlin.outputs.PackageStoreResponse.Companion.toKotlin(args0)
                })
            }),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/outputs/IntegrationRuntimeSsisPropertiesResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.outputs

import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 * SSIS properties for managed integration runtime.
 * @property catalogInfo Catalog information for managed dedicated integration runtime.
 * @property credential The credential reference containing authentication information.
 * @property customSetupScriptProperties Custom setup script properties for a managed dedicated integration runtime.
 * @property dataProxyProperties Data proxy properties for a managed dedicated integration runtime.
 * @property edition The edition for the SSIS Integration Runtime
 * @property expressCustomSetupProperties Custom setup without script properties for a SSIS integration runtime.
 * @property licenseType License type for bringing your own license scenario.
 * @property packageStores Package stores for the SSIS Integration Runtime.
 */
public data class IntegrationRuntimeSsisPropertiesResponse(
    public val catalogInfo: IntegrationRuntimeSsisCatalogInfoResponse? = null,
    public val credential: CredentialReferenceResponse? = null,
    public val customSetupScriptProperties: IntegrationRuntimeCustomSetupScriptPropertiesResponse? =
        null,
    public val dataProxyProperties: IntegrationRuntimeDataProxyPropertiesResponse? = null,
    public val edition: String? = null,
    public val expressCustomSetupProperties: List<Any>? = null,
    public val licenseType: String? = null,
    public val packageStores: List<PackageStoreResponse>? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.datafactory.outputs.IntegrationRuntimeSsisPropertiesResponse): IntegrationRuntimeSsisPropertiesResponse = IntegrationRuntimeSsisPropertiesResponse(
            catalogInfo = javaType.catalogInfo().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.datafactory.kotlin.outputs.IntegrationRuntimeSsisCatalogInfoResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            credential = javaType.credential().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.datafactory.kotlin.outputs.CredentialReferenceResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            customSetupScriptProperties = javaType.customSetupScriptProperties().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.datafactory.kotlin.outputs.IntegrationRuntimeCustomSetupScriptPropertiesResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            dataProxyProperties = javaType.dataProxyProperties().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.datafactory.kotlin.outputs.IntegrationRuntimeDataProxyPropertiesResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            edition = javaType.edition().map({ args0 -> args0 }).orElse(null),
            expressCustomSetupProperties = javaType.expressCustomSetupProperties().map({ args0 -> args0 }),
            licenseType = javaType.licenseType().map({ args0 -> args0 }).orElse(null),
            packageStores = javaType.packageStores().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.datafactory.kotlin.outputs.PackageStoreResponse.Companion.toKotlin(args0)
                })
            }),
        )
    }
}
